var class_ogre_1_1_codec =
[
    [ "~Codec", "class_ogre_1_1_codec.html#aee7d2a1126a22bbf3da40088495cb00b", null ],
    [ "registerCodec", "class_ogre_1_1_codec.html#a60f445cc6919df56af6611fd14eec47d", null ],
    [ "isCodecRegistered", "class_ogre_1_1_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557", null ],
    [ "unregisterCodec", "class_ogre_1_1_codec.html#a7aa2599cd9db05e590fb7f7786076852", null ],
    [ "getExtensions", "class_ogre_1_1_codec.html#a6092324fd74dd0221f7c63ca8bec4fc1", null ],
    [ "getCodec", "class_ogre_1_1_codec.html#aedb803489bfc3bcbf600ee6dfa2caf8a", null ],
    [ "getCodec", "class_ogre_1_1_codec.html#a938a753e65d5153ef2a3787eb7fe3630", null ],
    [ "encode", "class_ogre_1_1_codec.html#a8356df26fc21ff98ce8c1c66a2a2d784", null ],
    [ "encodeToFile", "class_ogre_1_1_codec.html#a5e7ecc1371add6ffa98d807dda1c8da3", null ],
    [ "decode", "class_ogre_1_1_codec.html#aa09f02c08e53d8e58835a7a342e8be64", null ],
    [ "getType", "class_ogre_1_1_codec.html#ada1a5477ab6a563565f1b3599d7b806a", null ],
    [ "magicNumberMatch", "class_ogre_1_1_codec.html#a2e3a2fbc93450efac141578d33c4bbc0", null ],
    [ "magicNumberToFileExt", "class_ogre_1_1_codec.html#af90756f690827353e18347d328bc5180", null ],
    [ "setParameter", "class_ogre_1_1_codec.html#a464e7b1ef3fae566425b2d7f4ed982db", null ]
];